spigot

package module
v0.0.0-...-e9eb4e2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2022 License: MIT Imports: 2 Imported by: 0

README

go-spigot-algo

Golang implementation of Unbounded Spigot algorithm for the digits of Pi.

Credits

Reference: https://rosettacode.org/wiki/Pi#Go

Action Items

  1. To deploy to Heroku
  2. To create endpoints for calling from FE.
  3. Enhance unit testing

Documentation

Index

Constants

This section is empty.

Variables

var (
	Precision = 1
)

Functions

func GetPi

func GetPi() string

GetPi returns the Pi value without decimal point (e.g. 31415xxx) containing Y digits representing precision.

Types

This section is empty.

Jump to